Граф коммитов

  • f7e311ba3d packaging/hip-rocclr.txt: multi-version install broken because of 'hip_rocclr' Cole Nelson 2020-06-24 12:00:43 -07:00
  • 35e429d10f packaging/hip-rocclr.txt: multi-version install broken because of 'hip_rocclr' Cole Nelson 2020-06-24 12:00:43 -07:00
  • 6b04a13e52 [dtest] hipMemcpyWithStream API multithreaded test scenarios rohit pathania 2020-06-02 10:08:26 -04:00
  • c14e95741b [dtest] hipMemcpyWithStream API multithreaded test scenarios rohit pathania 2020-06-02 10:08:26 -04:00
  • 1336a9de0b [dtest] hipMemcpyWithStream API multithreaded test scenarios rohit pathania 2020-06-02 10:08:26 -04:00
  • 32a6e854b7 [dtest] hipMemcpyWithStream API multithreaded test scenarios rohit pathania 2020-06-02 10:08:26 -04:00
  • 115c16cdde Code object reader improvements Tony 2020-06-20 06:45:32 -04:00
  • 91cb98dab6 Code object reader improvements Tony 2020-06-20 06:45:32 -04:00
  • 6678281480 JSON start point fix in multiproc usecase Evgeny 2020-06-24 16:59:44 -05:00
  • 60c106a07d JSON start point fix in multiproc usecase Evgeny 2020-06-24 16:59:44 -05:00
  • c4355292ed Merge "memcpy info added to csv, sqlitedb and json" into amd-master Rachida Kebichi 2020-06-25 10:18:24 -04:00
  • e539bc5dcd Merge "memcpy info added to csv, sqlitedb and json" into amd-master Rachida Kebichi 2020-06-25 10:18:24 -04:00
  • b223b9f084 memcpy info added to csv, sqlitedb and json Rachida Kebichi 2020-06-24 13:00:46 -04:00
  • 186a247dbe memcpy info added to csv, sqlitedb and json Rachida Kebichi 2020-06-24 13:00:46 -04:00
  • f35cba73c8 Merge pull request #48 from NVIDIA/fix-makefile-typo Sylvain Jeaugey 2020-06-24 14:52:55 -07:00
  • bd0755c95c Merge pull request #48 from NVIDIA/fix-makefile-typo Sylvain Jeaugey 2020-06-24 14:52:55 -07:00
  • 8b83a414c5 Fix typo in src/Makefile Luke Yeager 2020-06-24 14:39:22 -07:00
  • afdaf59b3b Fix typo in src/Makefile Luke Yeager 2020-06-24 14:39:22 -07:00
  • 7bdf69c167 Correctly set CMAKE_MODULE_PATH Vlad Sytchenko 2020-06-24 12:48:16 -04:00
  • 5fb771a195 Correctly set CMAKE_MODULE_PATH Vlad Sytchenko 2020-06-24 12:48:16 -04:00
  • 117f0f6e6e Revert use posix_memalign for network buffer allocation on host memory (#222) Wenkai Du 2020-06-24 11:25:55 -07:00
  • 84f8ba3bb0 Revert use posix_memalign for network buffer allocation on host memory (#222) Wenkai Du 2020-06-24 11:25:55 -07:00
  • d22c364abe cleanup Evgeny 2020-06-24 12:22:22 -05:00
  • f214238880 cleanup Evgeny 2020-06-24 12:22:22 -05:00
  • 179a9974f4 Revert "Support passing macros to hipLaunchKernelGGL" Ronak Nilesh Chauhan 2020-06-24 02:38:00 -04:00
  • b15e835d9e Revert "Support passing macros to hipLaunchKernelGGL" Ronak Nilesh Chauhan 2020-06-24 02:38:00 -04:00
  • b14dacc35f Revert "Support passing macros to hipLaunchKernelGGL" Ronak Nilesh Chauhan 2020-06-24 02:38:00 -04:00
  • b7101af203 Revert "Support passing macros to hipLaunchKernelGGL" Ronak Nilesh Chauhan 2020-06-24 02:38:00 -04:00
  • fa53a0a233 SWDEV-2 - Change OpenCL version number from 3167 to 3168 Chauncey Hui 2020-06-24 03:00:03 -04:00
  • 01d8a13065 SWDEV-2 - Change OpenCL version number from 3167 to 3168 Chauncey Hui 2020-06-24 03:00:03 -04:00
  • 0624d2cede Add gencode for CUDA11 Sylvain Jeaugey 2020-06-23 18:16:46 -07:00
  • b2603a2e85 Add gencode for CUDA11 Sylvain Jeaugey 2020-06-23 18:16:46 -07:00
  • c75faaaa37 concurrent sqtt support Evgeny 2020-06-10 11:00:18 -05:00
  • 9f7e936d70 concurrent sqtt support Evgeny 2020-06-10 11:00:18 -05:00
  • 3e2239b099 adding post initialization of HIP API pointer args to print returned by reference values Evgeny 2020-06-16 10:56:57 -05:00
  • a83acdae3a adding post initialization of HIP API pointer args to print returned by reference values Evgeny 2020-06-16 10:56:57 -05:00
  • cb337997db tblext.py fixing: 'stream_ind' not-inintialized python issue; app START time message; Evgeny 2020-06-22 17:27:55 -05:00
  • 708edfe989 tblext.py fixing: 'stream_ind' not-inintialized python issue; app START time message; Evgeny 2020-06-22 17:27:55 -05:00
  • 3e1f6435f8 Re-enable EDC reporting. Sean Keely 2020-06-23 18:23:50 -05:00
  • 71d85855d7 Re-enable EDC reporting. Sean Keely 2020-06-23 18:23:50 -05:00
  • 9273cfaa15 Support numa policy set by user Tao Sang 2020-06-15 19:13:58 -04:00
  • da94cd0de1 Support numa policy set by user Tao Sang 2020-06-15 19:13:58 -04:00
  • 328aa330b2 OAM: Add get dev and pci properties and sensor count Amber Lin 2020-05-25 17:20:11 -04:00
  • 9f72c8c08f OAM: Add get dev and pci properties and sensor count Amber Lin 2020-05-25 17:20:11 -04:00
  • 27deaea6e8 OAM: Add get dev and pci properties and sensor count Amber Lin 2020-05-25 17:20:11 -04:00
  • ec1205b497 Revert "Added file logging for rocclr & HIP" Vlad Sytchenko 2020-06-23 13:16:25 -04:00
  • 20c24cae93 Revert "Added file logging for rocclr & HIP" Vlad Sytchenko 2020-06-23 13:16:25 -04:00
  • 790d14d84b HIP-PROF: fixing pointers tracing Evgeny 2020-06-15 21:05:16 -05:00
  • c148adf362 HIP-PROF: fixing pointers tracing Evgeny 2020-06-15 21:05:16 -05:00
  • bab86e0e28 HIP-PROF: fixing pointers tracing Evgeny 2020-06-15 21:05:16 -05:00
  • a19960e79a HIP-PROF: fixing pointers tracing Evgeny 2020-06-15 21:05:16 -05:00
  • 4ca9b4512c profiler app-replay results merge fix; stream index postproc fix; Evgeny 2020-06-16 10:34:15 -05:00
  • 58fadcfa7c profiler app-replay results merge fix; stream index postproc fix; Evgeny 2020-06-16 10:34:15 -05:00
  • 39523e2c63 SWDEV-209747 - Staging Copy will not be supported in HIP, adjust test case accordingly. kjayapra-amd 2020-06-22 19:26:54 -04:00
  • a5c437c82e SWDEV-209747 - Staging Copy will not be supported in HIP, adjust test case accordingly. kjayapra-amd 2020-06-22 19:26:54 -04:00
  • b32c033585 SWDEV-209747 - Staging Copy will not be supported in HIP, adjust test case accordingly. kjayapra-amd 2020-06-22 19:26:54 -04:00
  • 04b58e6e50 SWDEV-209747 - Staging Copy will not be supported in HIP, adjust test case accordingly. kjayapra-amd 2020-06-22 19:26:54 -04:00
  • 6b83ac6e8f Merge "adding SQLiteDB class 'table_get_record' method" into amd-master Evgeny Shcherbakov 2020-06-23 13:10:23 -04:00
  • a2cc08811f Merge "adding SQLiteDB class 'table_get_record' method" into amd-master Evgeny Shcherbakov 2020-06-23 13:10:23 -04:00
  • 0e22fc3961 fixing rocminfo path requirements error - no usage printing Evgeny 2020-06-17 15:15:59 -05:00
  • a7179a1c5c fixing rocminfo path requirements error - no usage printing Evgeny 2020-06-17 15:15:59 -05:00
  • f2084f8fad Remove finding OpenCL library Jason Tang 2020-06-23 12:42:42 -04:00
  • 6f2dfea285 Remove finding OpenCL library Jason Tang 2020-06-23 12:42:42 -04:00
  • 37cad64f41 Update README Vlad Sytchenko 2020-06-22 16:48:23 -04:00
  • ed1c63877c Update README Vlad Sytchenko 2020-06-22 16:48:23 -04:00
  • dec7620abe Blit Object target and file should have different names Vlad Sytchenko 2020-06-22 16:24:53 -04:00
  • ea80e94756 Blit Object target and file should have different names Vlad Sytchenko 2020-06-22 16:24:53 -04:00
  • f184916c46 Fix missing numa symbol in building libamdocl64.so Tao Sang 2020-06-23 02:09:56 +00:00
  • 9171896d73 Fix missing numa symbol in building libamdocl64.so Tao Sang 2020-06-23 02:09:56 +00:00
  • 4644558c2b SWDEV-239297:hipMemset fix, getMemoryObject with unaligned ptr agodavar 2020-06-19 00:12:36 -04:00
  • 6a47458764 SWDEV-239297:hipMemset fix, getMemoryObject with unaligned ptr agodavar 2020-06-19 00:12:36 -04:00
  • a6c83e443c SWDEV-239297:hipMemset fix, getMemoryObject with unaligned ptr agodavar 2020-06-19 00:12:36 -04:00
  • 93da1b1f11 SWDEV-239297:hipMemset fix, getMemoryObject with unaligned ptr agodavar 2020-06-19 00:12:36 -04:00
  • bc5075c2c5 Added file logging for rocclr & HIP Sarbojit Sarkar 2020-06-11 05:33:40 -04:00
  • 5f055d227d Added file logging for rocclr & HIP Sarbojit Sarkar 2020-06-11 05:33:40 -04:00
  • 7511534bca SWDEV-2 - Change OpenCL version number from 3166 to 3167 Chauncey Hui 2020-06-23 03:00:03 -04:00
  • bafbbe663e SWDEV-2 - Change OpenCL version number from 3166 to 3167 Chauncey Hui 2020-06-23 03:00:03 -04:00
  • 9e57932639 Refactor rsmi to support oam Chris Freehill 2020-06-20 17:00:06 -05:00
  • 98b976ef3e Refactor rsmi to support oam Chris Freehill 2020-06-20 17:00:06 -05:00
  • 6594f8f58b Refactor rsmi to support oam Chris Freehill 2020-06-20 17:00:06 -05:00
  • 75b93b2dcd Disable maybe-uninitialized error reporting in GCC. Sean Keely 2020-06-22 13:13:48 -05:00
  • 2e1b863195 Disable maybe-uninitialized error reporting in GCC. Sean Keely 2020-06-22 13:13:48 -05:00
  • e7d664200f Use posix_memalign for network buffer allocation on host memory (#221) Wenkai Du 2020-06-22 13:06:25 -07:00
  • 0eb19a563a Use posix_memalign for network buffer allocation on host memory (#221) Wenkai Du 2020-06-22 13:06:25 -07:00
  • c59a81a4c8 Refactor IPC test files Ramesh Errabolu 2020-06-17 12:43:18 -05:00
  • 17bd3b7da5 Refactor IPC test files Ramesh Errabolu 2020-06-17 12:43:18 -05:00
  • f2490685ec Update licensing and remove duplicate licenses. Sean Keely 2020-06-19 16:28:13 -05:00
  • e9a4eff8a1 Update licensing and remove duplicate licenses. Sean Keely 2020-06-19 16:28:13 -05:00
  • 0dd2e2b010 Disable flush on marker German Andryeyev 2020-06-19 18:04:25 -04:00
  • 265d84bab9 Disable flush on marker German Andryeyev 2020-06-19 18:04:25 -04:00
  • f490ef4c87 Disable flush on marker German Andryeyev 2020-06-19 18:04:25 -04:00
  • 44c1df802e Disable flush on marker German Andryeyev 2020-06-19 18:04:25 -04:00
  • 3113312e03 Fix static lib crashing issue Tao Sang 2020-06-21 09:57:24 -04:00
  • d536a661ac Fix static lib crashing issue Tao Sang 2020-06-21 09:57:24 -04:00
  • 9c6dbda74b Fix static lib crashing issue Tao Sang 2020-06-21 09:57:24 -04:00
  • 0eebbb4f87 Fix static lib crashing issue Tao Sang 2020-06-21 09:57:24 -04:00
  • ebe5c3d381 Remove extra barriers German Andryeyev 2020-06-19 13:49:43 -04:00
  • c18892a590 Remove extra barriers German Andryeyev 2020-06-19 13:49:43 -04:00
  • 8f211fc9b0 cleanup Evgeny 2020-06-19 12:13:39 -05:00
  • 2c0c665398 cleanup Evgeny 2020-06-19 12:13:39 -05:00